<?php

/**
 * ⚠️ Editing not allowed except for 'en' language.
 *
 * @see https://github.com/monicahq/monica/blob/main/docs/contribute/translate.md for translations.
 */

return [
    'yes' => 'Có',
    'no' => 'Không',
    'update' => 'Cập nhật',
    'save' => 'Lưu',
    'add' => 'Thêm',
    'cancel' => 'Hủy',
    'confirm' => 'Xác nhận',
    'delete_confirm' => 'Bạn chắc chứ?',
    'delete' => 'Xóa',
    'edit' => 'Sửa',
    'upload' => 'Tải lên',
    'download' => 'Tải xuống',
    'save_close' => 'Lưu và đóng',
    'close' => 'Đóng',
    'copy' => 'Sao chép',
    'create' => 'Tạo',
    'remove' => 'Xoá',
    'revoke' => 'Thu hồi',
    'done' => 'Xong',
    'back' => 'Quay lại',
    'verify' => 'Xác minh',
    'new' => 'new',
    'unknown' => 'Tôi không biết',
    'load_more' => 'Hiển thị thêm',
    'loading' => 'Đang tải…',
    'with' => 'với',
    'today' => 'hôm nay',
    'yesterday' => 'hôm qua',
    'another_day' => 'ngày khác',
    'date' => 'Ngày',
    'type' => 'Kiểu',
    'zoom' => 'Phóng to / Thu nhỏ',
    'upgrade' => 'Nâng cấp để mở khóa',
    'percent_uploaded' => 'Đã tải lên {percent}%',
    'retry' => 'Thử lại',
    'filter' => 'Lọc danh sách',
    'go_back' => 'Quay lại',
    'file_selected' => '{count} tệp được chọn…',

    'application_title' => 'Monica – hệ thống quản trị quan hệ cá nhân',
    'application_description' => 'Monica là công cụ để quản lý tương tác của bạn với người yêu, bạn bè và gia đình.',
    'application_og_title' => 'Có một mối quan hệ tốt hơn với người bạn yêu thương. CRM miễn phí cho bạn và gia đình.',

    'markdown_description' => 'Muốn định dạng chữ tốt hơn? Chúng tôi hỗ trợ Markdown với chữ đậm, nghiêng, danh sách và nhiều hơn thế nữa.',
    'markdown_link' => 'Đọc tài liệu hướng dẫn',

    'header_settings_link' => 'Cài đặt',
    'header_logout_link' => 'Thoát',
    'header_changelog_link' => 'Cập nhật sản phẩm',

    'main_nav_cta' => 'Thêm người',
    'main_nav_dashboard' => 'Trang tổng quan',
    'main_nav_family' => 'Danh bạ',
    'main_nav_journal' => 'Nhật ký',
    'main_nav_activities' => 'Hoạt động',
    'main_nav_tasks' => 'Tác vụ',

    'footer_remarks' => 'Bình luận?',
    'footer_send_email' => 'Gửi email cho chúng tôi',
    'footer_privacy' => 'Chính sách quyền riêng tư',
    'footer_release' => 'Ghi chú phát hành',
    'footer_newsletter' => 'Bản tin',
    'footer_source_code' => 'Đóng góp',
    'footer_version' => 'Phiên bản: :version',
    'footer_new_version' => 'Đã có phiên bản mới của Monica',

    'footer_modal_version_whats_new' => 'Có gì mới',
    'footer_modal_version_release_away' => 'Bạn có :number bản cập nhật. Bạn nên cập nhật hệ thống.',

    'breadcrumb_dashboard' => 'Trang tổng quan',
    'breadcrumb_list_contacts' => 'Danh sách liên hệ',
    'breadcrumb_archived_contacts' => 'Liên hệ đã lưu trữ',
    'breadcrumb_journal' => 'Nhật ký',
    'breadcrumb_settings' => 'Cài đặt',
    'breadcrumb_settings_export' => 'Xuất',
    'breadcrumb_settings_users' => 'Người dùng',
    'breadcrumb_settings_users_add' => 'Thêm người dùng',
    'breadcrumb_settings_subscriptions' => 'Gói thuê bao',
    'breadcrumb_settings_import' => 'Nhập dữ liệu',
    'breadcrumb_settings_import_report' => 'Nhập báo cáo',
    'breadcrumb_settings_import_upload' => 'Tải lên',
    'breadcrumb_settings_tags' => 'Nhãn',
    'breadcrumb_add_significant_other' => 'Thêm điều trọng đại khác',
    'breadcrumb_edit_significant_other' => 'Sửa điều trọng đại khác',
    'breadcrumb_add_note' => 'Thêm ghi chú',
    'breadcrumb_edit_note' => 'Sửa ghi chú',
    'breadcrumb_api' => 'API',
    'breadcrumb_dav' => 'DAV Resources',
    'breadcrumb_edit_introductions' => 'Đã gặp nhau thế nào',
    'breadcrumb_settings_personalization' => 'Cá nhân hóa',
    'breadcrumb_settings_security' => 'Bảo mật',
    'breadcrumb_settings_security_2fa' => 'Xác thực 2 yếu tố',
    'breadcrumb_profile' => 'Hồ sơ của :name',

    'gender_male' => 'Nam',
    'gender_female' => 'Nữ',
    'gender_none' => 'Không tiết lộ',
    'gender_no_gender' => 'Không xác định giới tính',

    'error_title' => 'Rất tiếc! Đã xảy ra lỗi.',
    'error_unauthorized' => 'Bạn không có quyền chỉnh sửa tài nguyên này.',
    'error_user_account' => 'Người dùng này không thuộc về tài khoản nào.',
    'error_save' => 'Có lỗi khi lưu dữ liệu.',
    'error_try_again' => 'Có sự cố. Xin vui lòng thử lại.',
    'error_id' => 'ID lỗi: :id',
    'error_unavailable' => 'Dịch vụ không khả dụng',
    'error_maintenance' => 'Đang bảo trì. Chúng tôi sẽ trở lại ngay.',
    'error_help' => 'Chúng tôi sẽ trở lại ngay.',
    'error_twitter' => 'Follow <a href="https://twitter.com/:twitter">tài khoản Twitter</a> để nhận thông báo điều gì đang diễn ra.',
    'error_no_term' => 'Không có chính sách nào cho instance này.',

    'default_save_success' => 'Lưu dữ liệu thành công.',

    'compliance_title' => 'Xin lỗi vì sự gián đoạn.',
    'compliance_desc' => 'Chúng tôi đã thay đổi <a href=":urlterm" hreflang=":hreflang">Điều khoản sử dụng</a> và <a href=":url" hreflang=":hreflang">Chính sách bảo mật</a>. Theo luật chúng tôi phải hỏi bạn xem xét và chấp nhận chúng, sau đó bạn có thể tiếp tục sử dụng tài khoản của bạn.',
    'compliance_desc_end' => 'Chúng tôi không làm bất cứ điều gì xấu với dữ liệu hoặc tài khoản của bạn và chúng tôi sẽ không bao giờ làm như vậy.',
    'compliance_terms' => 'Đồng ý điều khoản mới',

    // Relationship types
    // Yes, each relationship type has 8 strings associated with it.
    // This is because we need to indicate the name of the relationship type,
    // and also the name of the opposite side of this relationship (father/son),
    // and then, the feminine version of the string. Finally, in some sentences
    // in the UI, we need to include the name of the person we add the relationship
    // to.
    'relationship_type_group_love' => 'Mối quan hệ tình cảm',
    'relationship_type_group_family' => 'Mối quan hệ gia đình',
    'relationship_type_group_friend' => 'Mối quan hệ bạn bè',
    'relationship_type_group_work' => 'Mối quan hệ công việc',
    'relationship_type_group_other' => 'Các mối quan hệ khác',

    'relationship_type_partner' => 'điều trọng đại khác',
    'relationship_type_partner_female' => 'điều trọng đại khác',
    'relationship_type_partner_male' => 'significant other',
    'relationship_type_partner_with_name' => 'người quan trọng với :name',
    'relationship_type_partner_female_with_name' => 'người quan trọng với :name',
    'relationship_type_partner_male_with_name' => ':name’s significant other',

    'relationship_type_spouse' => 'vợ/chồng',
    'relationship_type_spouse_female' => 'wife',
    'relationship_type_spouse_male' => 'husband',
    'relationship_type_spouse_with_name' => 'chồng của :name',
    'relationship_type_spouse_female_with_name' => ':name’s wife',
    'relationship_type_spouse_male_with_name' => ':name’s husband',

    'relationship_type_date' => 'hẹn hò',
    'relationship_type_date_female' => 'hẹn hò',
    'relationship_type_date_male' => 'date',
    'relationship_type_date_with_name' => 'hẹn hò với :name',
    'relationship_type_date_female_with_name' => 'hẹn hò với :name',
    'relationship_type_date_male_with_name' => ':name’s date',

    'relationship_type_lover' => 'người yêu',
    'relationship_type_lover_female' => 'người yêu',
    'relationship_type_lover_male' => 'lover',
    'relationship_type_lover_with_name' => 'người yêu của :name',
    'relationship_type_lover_female_with_name' => 'người yêu của :name',
    'relationship_type_lover_male_with_name' => ':name’s lover',

    'relationship_type_inlovewith' => 'có tình cảm với',
    'relationship_type_inlovewith_female' => 'có tình cảm với',
    'relationship_type_inlovewith_male' => 'in love with',
    'relationship_type_inlovewith_with_name' => 'ai đó :name có tình cảm',
    'relationship_type_inlovewith_female_with_name' => 'ai đó :name có tình cảm',
    'relationship_type_inlovewith_male_with_name' => 'someone :name is in love with',

    'relationship_type_lovedby' => 'được thích bởi',
    'relationship_type_lovedby_female' => 'được thích bởi',
    'relationship_type_lovedby_male' => 'loved by',
    'relationship_type_lovedby_with_name' => 'người tình bí mật của :name',
    'relationship_type_lovedby_female_with_name' => 'người tình bí mật của :name',
    'relationship_type_lovedby_male_with_name' => ':name’s secret lover',

    'relationship_type_ex' => 'ex-partner',
    'relationship_type_ex_female' => 'người yêu cũ',
    'relationship_type_ex_male' => 'ex-boyfriend',
    'relationship_type_ex_with_name' => ':name’s ex-partner',
    'relationship_type_ex_female_with_name' => 'người yêu cũ của :name',
    'relationship_type_ex_male_with_name' => ':name’s ex-boyfriend',

    'relationship_type_parent' => 'parent',
    'relationship_type_parent_female' => 'mẹ',
    'relationship_type_parent_male' => 'father',
    'relationship_type_parent_with_name' => ':name’s parent',
    'relationship_type_parent_female_with_name' => 'mẹ của :name',
    'relationship_type_parent_male_with_name' => ':name’s father',

    'relationship_type_child' => 'child',
    'relationship_type_child_female' => 'con gái',
    'relationship_type_child_male' => 'son',
    'relationship_type_child_with_name' => ':name’s child',
    'relationship_type_child_female_with_name' => 'con gái của :name',
    'relationship_type_child_male_with_name' => ':name’s son',

    'relationship_type_stepparent' => 'step-parent',
    'relationship_type_stepparent_female' => 'mẹ kế',
    'relationship_type_stepparent_male' => 'stepfather',
    'relationship_type_stepparent_with_name' => ':name’s step-parent',
    'relationship_type_stepparent_female_with_name' => 'mẹ kế của :name',
    'relationship_type_stepparent_male_with_name' => ':name’s stepfather',

    'relationship_type_stepchild' => 'stepchild',
    'relationship_type_stepchild_female' => 'con gái riêng',
    'relationship_type_stepchild_male' => 'stepson',
    'relationship_type_stepchild_with_name' => ':name’s stepchild',
    'relationship_type_stepchild_female_with_name' => 'con gái riêng của :name',
    'relationship_type_stepchild_male_with_name' => ':name’s stepson',

    'relationship_type_sibling' => 'sibling',
    'relationship_type_sibling_female' => 'Chị em gái',
    'relationship_type_sibling_male' => 'brother',
    'relationship_type_sibling_with_name' => ':name’s sibling',
    'relationship_type_sibling_female_with_name' => 'chị gái của :name',
    'relationship_type_sibling_male_with_name' => ':name’s brother',

    'relationship_type_grandparent' => 'grandparent',
    'relationship_type_grandparent_female' => 'grandmother',
    'relationship_type_grandparent_male' => 'grandfather',
    'relationship_type_grandparent_with_name' => ':name’s grandparent',
    'relationship_type_grandparent_female_with_name' => ':name’s grandmother',
    'relationship_type_grandparent_male_with_name' => ':name’s grandfather',

    'relationship_type_grandchild' => 'grandchild',
    'relationship_type_grandchild_female' => 'granddaughter',
    'relationship_type_grandchild_male' => 'grandson',
    'relationship_type_grandchild_with_name' => ':name’s grandchild',
    'relationship_type_grandchild_female_with_name' => ':name’s granddauther',
    'relationship_type_grandchild_male_with_name' => ':name’s grandson',

    'relationship_type_uncle' => 'chú/bác',
    'relationship_type_uncle_female' => 'cô/dì',
    'relationship_type_uncle_male' => 'uncle',
    'relationship_type_uncle_with_name' => 'chú/bác của :name',
    'relationship_type_uncle_female_with_name' => 'cô/dì của :name',
    'relationship_type_uncle_male_with_name' => ':name’s uncle',

    'relationship_type_nephew' => 'cháu trai',
    'relationship_type_nephew_female' => 'cháu gái',
    'relationship_type_nephew_male' => 'nephew',
    'relationship_type_nephew_with_name' => 'cháu trai của :name',
    'relationship_type_nephew_female_with_name' => 'cháu gái của :name',
    'relationship_type_nephew_male_with_name' => ':name’s nephew',

    'relationship_type_cousin' => 'anh em họ',
    'relationship_type_cousin_female' => 'anh em họ',
    'relationship_type_cousin_male' => 'cousin',
    'relationship_type_cousin_with_name' => 'anh em họ của :name',
    'relationship_type_cousin_female_with_name' => 'anh em họ của :name',
    'relationship_type_cousin_male_with_name' => ':name’s cousin',

    'relationship_type_godfather' => 'godparent',
    'relationship_type_godfather_female' => 'mẹ đỡ đầu',
    'relationship_type_godfather_male' => 'godfather',
    'relationship_type_godfather_with_name' => ':name’s godparent',
    'relationship_type_godfather_female_with_name' => 'mẹ đỡ đầu của :name',
    'relationship_type_godfather_male_with_name' => ':name’s godfather',

    'relationship_type_godson' => 'godchild',
    'relationship_type_godson_female' => 'con gái đỡ đầu',
    'relationship_type_godson_male' => 'godson',
    'relationship_type_godson_with_name' => ':name’s godchild',
    'relationship_type_godson_female_with_name' => 'con gái đỡ đầu của :name',
    'relationship_type_godson_male_with_name' => ':name’s godson',

    'relationship_type_friend' => 'bạn bè',
    'relationship_type_friend_female' => 'bạn bè',
    'relationship_type_friend_male' => 'friend',
    'relationship_type_friend_with_name' => 'bạn của :name',
    'relationship_type_friend_female_with_name' => 'bạn của :name',
    'relationship_type_friend_male_with_name' => ':name’s friend',

    'relationship_type_bestfriend' => 'bạn thân',
    'relationship_type_bestfriend_female' => 'bạn thân',
    'relationship_type_bestfriend_male' => 'best friend',
    'relationship_type_bestfriend_with_name' => 'bạn thân của :name',
    'relationship_type_bestfriend_female_with_name' => 'bạn thân của :name',
    'relationship_type_bestfriend_male_with_name' => ':name’s best friend',

    'relationship_type_colleague' => 'đồng nghiệp',
    'relationship_type_colleague_female' => 'đồng nghiệp',
    'relationship_type_colleague_male' => 'colleague',
    'relationship_type_colleague_with_name' => 'dồng nghiệp của :name',
    'relationship_type_colleague_female_with_name' => 'dồng nghiệp của :name',
    'relationship_type_colleague_male_with_name' => ':name’s colleague',

    'relationship_type_boss' => 'sếp',
    'relationship_type_boss_female' => 'sếp',
    'relationship_type_boss_male' => 'boss',
    'relationship_type_boss_with_name' => 'sếp của :name',
    'relationship_type_boss_female_with_name' => 'sếp của :name',
    'relationship_type_boss_male_with_name' => ':name’s boss',

    'relationship_type_subordinate' => 'cấp dưới',
    'relationship_type_subordinate_female' => 'cấp dưới',
    'relationship_type_subordinate_male' => 'subordinate',
    'relationship_type_subordinate_with_name' => 'cấp dưới của :name',
    'relationship_type_subordinate_female_with_name' => 'cấp dưới của :name',
    'relationship_type_subordinate_male_with_name' => ':name’s subordinate',

    'relationship_type_mentor' => 'người hướng dẫn',
    'relationship_type_mentor_female' => 'người hướng dẫn',
    'relationship_type_mentor_male' => 'mentor',
    'relationship_type_mentor_with_name' => 'người hướng dẫn của :name',
    'relationship_type_mentor_female_with_name' => 'người hướng dẫn của :name',
    'relationship_type_mentor_male_with_name' => ':name’s mentor',

    'relationship_type_protege' => 'protégé',
    'relationship_type_protege_female' => 'protégé',
    'relationship_type_protege_male' => 'protégé',
    'relationship_type_protege_with_name' => ':name’s protégé',
    'relationship_type_protege_female_with_name' => ':name’s protégé',
    'relationship_type_protege_male_with_name' => ':name’s protégé',

    'relationship_type_ex_husband' => 'ex-spouse',
    'relationship_type_ex_husband_female' => 'vợ cũ',
    'relationship_type_ex_husband_male' => 'ex-husband',
    'relationship_type_ex_husband_with_name' => ':name’s ex-spouse',
    'relationship_type_ex_husband_female_with_name' => 'vợ cũ của :name',
    'relationship_type_ex_husband_male_with_name' => ':name’s ex-husband',

    // emotions
    'emotion_primary_love' => 'Yêu',
    'emotion_primary_joy' => 'Vui sướng',
    'emotion_primary_surprise' => 'Ngạc nhiên',
    'emotion_primary_anger' => 'Tức giận',
    'emotion_primary_sadness' => 'Buồn bã',
    'emotion_primary_fear' => 'Sợ hãi',

    'emotion_secondary_affection' => 'Cảm kích',
    'emotion_secondary_lust' => 'Ham muốn',
    'emotion_secondary_longing' => 'Ao ước',
    'emotion_secondary_cheerfulness' => 'Vui vẻ',
    'emotion_secondary_zest' => 'Hăng hái',
    'emotion_secondary_contentment' => 'Hài lòng',
    'emotion_secondary_pride' => 'Tự hào',
    'emotion_secondary_optimism' => 'Lạc quan',
    'emotion_secondary_enthrallment' => 'Say mê',
    'emotion_secondary_relief' => 'Cứu trợ',
    'emotion_secondary_surprise' => 'Ngạc nhiên',
    'emotion_secondary_irritation' => 'Kích thích',
    'emotion_secondary_exasperation' => 'Bực tức',
    'emotion_secondary_rage' => 'Thịnh nộ',
    'emotion_secondary_disgust' => 'Chán ghét',
    'emotion_secondary_envy' => 'Đố kị',
    'emotion_secondary_suffering' => 'Đau khổ',
    'emotion_secondary_sadness' => 'Buồn bã',
    'emotion_secondary_disappointment' => 'Thất vọng',
    'emotion_secondary_shame' => 'Xấu hổ',
    'emotion_secondary_neglect' => 'Bỏ bê',
    'emotion_secondary_sympathy' => 'Cảm thông',
    'emotion_secondary_horror' => 'Ghê rợn',
    'emotion_secondary_nervousness' => 'Lo lắng',

    'emotion_adoration' => 'Yêu mến',
    'emotion_affection' => 'Cảm kích',
    'emotion_love' => 'Yêu',
    'emotion_fondness' => 'Thương mến',
    'emotion_liking' => 'Có thiện cảm',
    'emotion_attraction' => 'Thu hút',
    'emotion_caring' => 'Chăm sóc',
    'emotion_tenderness' => 'Nhạy cảm',
    'emotion_compassion' => 'Thương xót',
    'emotion_sentimentality' => 'Đa cảm',
    'emotion_arousal' => 'Thức tỉnh',
    'emotion_desire' => 'Khao khát',
    'emotion_lust' => 'Ham muốn',
    'emotion_passion' => 'Đam mê',
    'emotion_infatuation' => 'Mê đắm',
    'emotion_longing' => 'Ao ước',
    'emotion_amusement' => 'Thích thú',
    'emotion_bliss' => 'Hạnh phúc',
    'emotion_cheerfulness' => 'Hân hoan',
    'emotion_gaiety' => 'Tươi vui',
    'emotion_glee' => 'Hân hoan',
    'emotion_jolliness' => 'Vui vẻ',
    'emotion_joviality' => 'Tâm hồn vui vẻ',
    'emotion_joy' => 'Vui sướng',
    'emotion_delight' => 'Delight',
    'emotion_enjoyment' => 'Enjoyment',
    'emotion_gladness' => 'Gladness',
    'emotion_happiness' => 'Happiness',
    'emotion_jubilation' => 'Hân hoan',
    'emotion_elation' => 'Phấn khởi',
    'emotion_satisfaction' => 'Satisfaction',
    'emotion_ecstasy' => 'Ecstasy',
    'emotion_euphoria' => 'Euphoria',
    'emotion_enthusiasm' => 'Enthusiasm',
    'emotion_zeal' => 'Zeal',
    'emotion_zest' => 'Zest',
    'emotion_excitement' => 'Hứng thú',
    'emotion_thrill' => 'Thrill',
    'emotion_exhilaration' => 'Exhilaration',
    'emotion_contentment' => 'Contentment',
    'emotion_pleasure' => 'Pleasure',
    'emotion_pride' => 'Pride',
    'emotion_eagerness' => 'Eagerness',
    'emotion_hope' => 'Hy vọng',
    'emotion_optimism' => 'Optimism',
    'emotion_enthrallment' => 'Enthrallment',
    'emotion_rapture' => 'Rapture',
    'emotion_relief' => 'Relief',
    'emotion_amazement' => 'Amazement',
    'emotion_surprise' => 'Surprise',
    'emotion_astonishment' => 'Astonishment',
    'emotion_aggravation' => 'Aggravation',
    'emotion_irritation' => 'Irritation',
    'emotion_agitation' => 'Agitation',
    'emotion_annoyance' => 'Annoyance',
    'emotion_grouchiness' => 'Grouchiness',
    'emotion_grumpiness' => 'Grumpiness',
    'emotion_exasperation' => 'Exasperation',
    'emotion_frustration' => 'Frustration',
    'emotion_anger' => 'Anger',
    'emotion_rage' => 'Rage',
    'emotion_outrage' => 'Outrage',
    'emotion_fury' => 'Fury',
    'emotion_wrath' => 'Wrath',
    'emotion_hostility' => 'Hostility',
    'emotion_ferocity' => 'Ferocity',
    'emotion_bitterness' => 'Bitterness',
    'emotion_hate' => 'Hate',
    'emotion_loathing' => 'Loathing',
    'emotion_scorn' => 'Scorn',
    'emotion_spite' => 'Spite',
    'emotion_vengefulness' => 'Vengefulness',
    'emotion_dislike' => 'Không thích',
    'emotion_resentment' => 'Resentment',
    'emotion_disgust' => 'Disgust',
    'emotion_revulsion' => 'Revulsion',
    'emotion_contempt' => 'Contempt',
    'emotion_envy' => 'Envy',
    'emotion_jealousy' => 'Jealousy',
    'emotion_agony' => 'Agony',
    'emotion_suffering' => 'Suffering',
    'emotion_hurt' => 'Tổn thương',
    'emotion_anguish' => 'Anguish',
    'emotion_depression' => 'Depression',
    'emotion_despair' => 'Despair',
    'emotion_hopelessness' => 'Hopelessness',
    'emotion_gloom' => 'Gloom',
    'emotion_glumness' => 'Glumness',
    'emotion_sadness' => 'Sadness',
    'emotion_unhappiness' => 'Unhappiness',
    'emotion_grief' => 'Grief',
    'emotion_sorrow' => 'Sorrow',
    'emotion_woe' => 'Woe',
    'emotion_misery' => 'Misery',
    'emotion_melancholy' => 'Melancholy',
    'emotion_dismay' => 'Dismay',
    'emotion_disappointment' => 'Disappointment',
    'emotion_displeasure' => 'Displeasure',
    'emotion_guilt' => 'Guilt',
    'emotion_shame' => 'Shame',
    'emotion_regret' => 'Hối tiếc',
    'emotion_remorse' => 'Remorse',
    'emotion_alienation' => 'Alienation',
    'emotion_isolation' => 'Isolation',
    'emotion_neglect' => 'Neglect',
    'emotion_loneliness' => 'Loneliness',
    'emotion_rejection' => 'Rejection',
    'emotion_homesickness' => 'Homesickness',
    'emotion_defeat' => 'Defeat',
    'emotion_dejection' => 'Dejection',
    'emotion_insecurity' => 'Không an toàn',
    'emotion_embarrassment' => 'Embarrassment',
    'emotion_humiliation' => 'Humiliation',
    'emotion_insult' => 'Insult',
    'emotion_pity' => 'Pity',
    'emotion_sympathy' => 'Sympathy',
    'emotion_alarm' => 'Báo động',
    'emotion_shock' => 'Shock',
    'emotion_fear' => 'Sợ hãi',
    'emotion_fright' => 'Fright',
    'emotion_horror' => 'Ghê rợn',
    'emotion_terror' => 'Khủng bố',
    'emotion_panic' => 'Hoảng sợ',
    'emotion_hysteria' => 'Hysteria',
    'emotion_mortification' => 'Mortification',
    'emotion_anxiety' => 'Anxiety',
    'emotion_nervousness' => 'Lo lắng',
    'emotion_tenseness' => 'Tenseness',
    'emotion_uneasiness' => 'Uneasiness',
    'emotion_apprehension' => 'Apprehension',
    'emotion_worry' => 'Lo lắng',
    'emotion_distress' => 'Distress',
    'emotion_dread' => 'Dread',

    // weather
    'weather_sunny' => 'Có nắng',
    'weather_clear' => 'Trời quang, ít mây',
    'weather_clear-day' => 'Ngày đẹp trời',
    'weather_clear-night' => 'Đêm quang đãng',
    'weather_light-drizzle' => 'Mưa phùn',
    'weather_patchy-light-drizzle' => 'Patchy light drizzle',
    'weather_patchy-light-rain' => 'Patchy light rain',
    'weather_light-rain' => 'Light rain',
    'weather_moderate-rain-at-times' => 'Moderate rain at times',
    'weather_moderate-rain' => 'Moderate rain',
    'weather_patchy-rain-possible' => 'Patchy rain possible',
    'weather_heavy-rain-at-times' => 'Heavy rain at times',
    'weather_heavy-rain' => 'Heavy rain',
    'weather_light-freezing-rain' => 'Light freezing rain',
    'weather_moderate-or-heavy-freezing-rain' => 'Moderate or heavy freezing rain',
    'weather_light-sleet' => 'Light sleet',
    'weather_moderate-or-heavy-rain-shower' => 'Moderate or heavy rain shower',
    'weather_light-rain-shower' => 'Light rain shower',
    'weather_torrential-rain-shower' => 'Torrential rain shower',
    'weather_rain' => 'Mưa',
    'weather_snow' => 'Tuyết',
    'weather_blowing-snow' => 'Blowing snow',
    'weather_patchy-light-snow' => 'Patchy light snow',
    'weather_light-snow' => 'Light snow',
    'weather_patchy-moderate-snow' => 'Patchy moderate snow',
    'weather_moderate-snow' => 'Moderate snow',
    'weather_patchy-heavy-snow' => 'Patchy heavy snow',
    'weather_heavy-snow' => 'Heavy snow',
    'weather_light-snow-showers' => 'Light snow showers',
    'weather_moderate-or-heavy-snow-showers' => 'Moderate or heavy snow showers',
    'weather_patchy-snow-possible' => 'Patchy snow possible',
    'weather_patchy-sleet-possible' => 'Patchy sleet possible',
    'weather_moderate-or-heavy-sleet' => 'Moderate or heavy sleet',
    'weather_light-sleet-showers' => 'Light sleet showers',
    'weather_moderate-or-heavy-sleet-showers' => 'Moderate or heavy sleet showers',
    'weather_sleet' => 'Mưa tuyết',
    'weather_wind' => 'Gió',
    'weather_fog' => 'Sương mù',
    'weather_freezing-fog' => 'Freezing fog',
    'weather_mist' => 'Mist',
    'weather_blizzard' => 'Blizzard',
    'weather_overcast' => 'Overcast',
    'weather_cloudy' => 'Nhiều mây',
    'weather_partly-cloudy-day' => 'Partly cloudy',
    'weather_partly-cloudy-night' => 'Partly cloudy',
    'weather_freezing-drizzle' => 'Freezing drizzle',
    'weather_heavy-freezing-drizzle' => 'Heavy freezing drizzle',
    'weather_patchy-freezing-drizzle-possible' => 'Patchy freezing drizzle possible',
    'weather_ice-pellets' => 'Ice pellets',
    'weather_light-showers-of-ice-pellets' => 'Light showers of ice pellets',
    'weather_moderate-or-heavy-showers-of-ice-pellets' => 'Moderate or heavy showers of ice pellets',
    'weather_thundery-outbreaks-possible' => 'Thundery outbreaks possible',
    'weather_patchy-light-rain-with-thunder' => 'Patchy light rain with thunder',
    'weather_moderate-or-heavy-rain-with-thunder' => 'Moderate or heavy rain with thunder',
    'weather_patchy-light-snow-with-thunder' => 'Patchy light snow with thunder',
    'weather_moderate-or-heavy-snow-with-thunder' => 'Moderate or heavy snow with thunder',
    'weather_current_temperature_celsius' => ':temperature °C',
    'weather_current_temperature_fahrenheit' => ':temperature °F',
    'weather_current_title' => 'Thời tiết hiện tại',

    // dav
    'dav_contacts' => 'Danh bạ',
    'dav_contacts_description' => 'danh bạ của :name',
    'dav_birthdays' => 'Sinh nhật',
    'dav_birthdays_description' => ':name’s contact’s birthdays',
    'dav_tasks' => 'Nhiệm vụ',
    'dav_tasks_description' => 'nhiệm vụ của :name',

    // contact list
    'contact_list_avatar' => 'Ảnh đại diện',
    'contact_list_name' => 'Liên hệ',
    'contact_list_description' => 'Mô tả',

];
